<?php
/**
 * Nexter Font Families List
 *
 * @package	Nexter
 * @since	1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/*
 * Nexter Fonts Listing
 * Google fonts list, Default(System) fonts list and Custom fonts list in Nexter
 */
if ( ! class_exists( 'Nexter_Font_Families_Listing' ) ) {

	final class Nexter_Font_Families_Listing {
		
		/**
		 * Default Fonts
		 */
		public static $default_fonts_list = array();
		
		/**
		 * Google Fonts
		 */
		public static $google_fonts_list = array();
		
		/**
		 * Get Google Fonts List
		 */
		public static function get_google_fonts_load() {

			if ( empty( self::$google_fonts_list ) ) {
				
				$google_fonts_list_file = apply_filters( 'nexter_google_fonts_load_array', NXT_THEME_DIR . 'inc/customizer/nexter-google-font-list.php' );

				if ( ! file_exists( $google_fonts_list_file ) ) {
					return array();
				}

				$google_fonts_list_array = include $google_fonts_list_file;

				foreach ( $google_fonts_list_array as $key => $gfonts ) {
				
					self::$google_fonts_list[ $key ][] = array_values( $gfonts[ 'variants' ] );
					self::$google_fonts_list[ $key ][] =  $gfonts[ 'category' ];
				}
			}
			return apply_filters( 'nexter_google_fonts_load', self::$google_fonts_list );
		}
		
		/**
		 * Get Default Fonts List
		 */
		public static function get_default_fonts_load() {
			if ( empty( self::$default_fonts_list ) ) {
				self::$default_fonts_list = [
					'Helvetica' => [
						'fallback' => 'Verdana, Arial, sans-serif',
						'weights'  => [ '300', '400', '700' ],
					],
					'Times'     => [
						'fallback' => 'Georgia, serif',
						'weights'  => [ '300', '400', '700' ],
					],
					'Verdana'   => [
						'fallback' => 'Helvetica, Arial, sans-serif',
						'weights'  => [ '300', '400', '700' ],
					],
					'Arial'     => [
						'fallback' => 'Helvetica, Verdana, sans-serif',
						'weights'  => [ '300','400','700' ],
					],
				];
			}

			return apply_filters( 'nexter_default_fonts_list', self::$default_fonts_list );
		}
		
		/**
		 * Custom Fonts List
		 */
		public static function get_custom_fonts_load() {
			$custom_fonts_list = [];
			return apply_filters( 'nexter_custom_fonts_load', $custom_fonts_list );
		}

	}
}